.. _spkg_decorator:

decorator: Python library providing decorators
==============================================

Description
-----------

Better living through Python with decorators


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    5.2.1

version_requirements.txt::

    decorator >=4.4.0

See https://repology.org/project/python:decorator/versions

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install decorator\>=4.4.0

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i decorator

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-decorator

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install decorator

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-decorator

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-decorator

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/decorator

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-decorator

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-decorator

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3-decorator

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-decorator


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
